{% load staticfiles %}{% load url from future %}{% load i18n %}<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8">
        <title>{% block fulltitle %}{% block title %}{% endblock %}{% endblock %}</title>

        {% block extra_headers %}{% endblock %}

        {% block extra_css %}
            <link href="{% static "speeches/css/speeches.css" %}" rel="stylesheet" type="text/css">
        {% endblock extra_css %}

        <script type="text/javascript" src="{% static "speeches/js/jquery.js" %}" charset="utf-8"></script>
        {% block extra_js_head %}{% endblock %}
    </head>

    <body id="top">

        <header>
          <div class="full-page__row">
            <div class="full-page__unit">
              <h1><a href="{% url 'speeches:home' %}">SayIt</a></h1>

              <ul class="inline-list">
                <li><a href="{% url 'speeches:home' %}">{% trans 'Home' %}</a></li>
                <li><a href="{% url 'speeches:speaker-list' %}">{% trans 'Speakers' %}</a></li>
                <li><a href="{% url 'speeches:parentless-list' %}">{% trans 'Speeches' %}</a></li>
              </ul>
            </div>
          </div>
        </header>

        <div class="full-page">
          <div class="full-page__row">
            <div class="full-page__unit">
              {% for message in messages %}
                <div class="alert alert-{{ message.tags }}">
                  {{ message }}
                </div>
              {% endfor %}

              {% block content %}{% endblock %}

            </div>
          </div>
        </div>

        <script type="text/javascript" src="{% static "speeches/js/foundation/foundation.js" %}" charset="utf-8"></script>
        <script type="text/javascript" src="{% static "speeches/js/foundation/foundation.dropdown.js" %}" charset="utf-8"></script>
        <script type="text/javascript" src="{% static "speeches/js/speeches.js" %}" charset="utf-8"></script>
        {% block extra_js %}{% endblock %}
        <script>
          if (typeof $ != 'undefined' && typeof $(document).foundation != 'undefined') {
            $(document).foundation();
          }
        </script>

    </body>
</html>
